pub fn zip_eq<I, J>(i: I, j: J) -> ZipEq<I::IntoIter, J::IntoIter> ⓘwhere
I: IntoIterator,
J: IntoIterator,Expand description
Zips two iterators but panics if they are not of the same length.
pub fn zip_eq<I, J>(i: I, j: J) -> ZipEq<I::IntoIter, J::IntoIter> ⓘwhere
I: IntoIterator,
J: IntoIterator,Zips two iterators but panics if they are not of the same length.