#[repr(transparent)]pub struct TotalOrdWrap<T>(pub T);Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone> Clone for TotalOrdWrap<T>
impl<T: Clone> Clone for TotalOrdWrap<T>
impl<T: Copy> Copy for TotalOrdWrap<T>
Sourceimpl<T: Debug> Debug for TotalOrdWrap<T>
impl<T: Debug> Debug for TotalOrdWrap<T>
Sourceimpl<'de, T> Deserialize<'de> for TotalOrdWrap<T>where
T: Deserialize<'de>,
Available on crate feature serde only.
impl<'de, T> Deserialize<'de> for TotalOrdWrap<T>where
T: Deserialize<'de>,
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T: DirtyHash> DirtyHash for TotalOrdWrap<T>
impl<T: DirtyHash> DirtyHash for TotalOrdWrap<T>
fn dirty_hash(&self) -> u64
impl<T: TotalEq> Eq for TotalOrdWrap<T>
Sourceimpl<T: TotalHash> Hash for TotalOrdWrap<T>
impl<T: TotalHash> Hash for TotalOrdWrap<T>
Sourceimpl<T: IsNull> IsNull for TotalOrdWrap<T>
impl<T: IsNull> IsNull for TotalOrdWrap<T>
Sourceimpl<T> JsonSchema for TotalOrdWrap<T>where
T: JsonSchema,
Available on crate feature dsl-schema only.
impl<T> JsonSchema for TotalOrdWrap<T>where
T: JsonSchema,
Available on crate feature
dsl-schema only.Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl<T: TotalOrd> Ord for TotalOrdWrap<T>
impl<T: TotalOrd> Ord for TotalOrdWrap<T>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl<T: TotalEq> PartialEq for TotalOrdWrap<T>
impl<T: TotalEq> PartialEq for TotalOrdWrap<T>
Sourceimpl<T: TotalOrd> PartialOrd for TotalOrdWrap<T>
impl<T: TotalOrd> PartialOrd for TotalOrdWrap<T>
Sourceimpl<T> Serialize for TotalOrdWrap<T>where
T: Serialize,
Available on crate feature serde only.
impl<T> Serialize for TotalOrdWrap<T>where
T: Serialize,
Available on crate feature
serde only.Sourceimpl<T> TransparentWrapper<T> for TotalOrdWrap<T>
impl<T> TransparentWrapper<T> for TotalOrdWrap<T>
fn wrap_ref(s: &Inner) -> &Self
fn wrap_ref(s: &Inner) -> &Self
Convert a reference to the inner type into a reference to the wrapper
type.
fn wrap_mut(s: &mut Inner) -> &mut Self
fn wrap_mut(s: &mut Inner) -> &mut Self
Convert a mutable reference to the inner type into a mutable reference to
the wrapper type.
fn wrap_slice(s: &[Inner]) -> &[Self]
fn wrap_slice(s: &[Inner]) -> &[Self]
Convert a slice to the inner type into a slice to the wrapper type.
fn wrap_slice_mut(s: &mut [Inner]) -> &mut [Self]
fn wrap_slice_mut(s: &mut [Inner]) -> &mut [Self]
Convert a mutable slice to the inner type into a mutable slice to the
wrapper type.
fn peel_ref(s: &Self) -> &Inner
fn peel_ref(s: &Self) -> &Inner
Convert a reference to the wrapper type into a reference to the inner
type.
fn peel_mut(s: &mut Self) -> &mut Inner
fn peel_mut(s: &mut Self) -> &mut Inner
Convert a mutable reference to the wrapper type into a mutable reference
to the inner type.
fn peel_slice(s: &[Self]) -> &[Inner]
fn peel_slice(s: &[Self]) -> &[Inner]
Convert a slice to the wrapped type into a slice to the inner type.
fn peel_slice_mut(s: &mut [Self]) -> &mut [Inner]
fn peel_slice_mut(s: &mut [Self]) -> &mut [Inner]
Convert a mutable slice to the wrapped type into a mutable slice to the
inner type.