TotalEq

Trait TotalEq 

pub trait TotalEq {
    // Required method
    fn tot_eq(&self, other: &Self) -> bool;

    // Provided method
    fn tot_ne(&self, other: &Self) -> bool { ... }
}
Alternative trait for Eq. By consistently using this we can still be generic w.r.t Eq while getting a total ordering for floats.

Required Methods

fn tot_eq(&self, other: &Self) -> bool

Provided Methods

fn tot_ne(&self, other: &Self) -> bool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TotalEq for &[u8]

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for &str

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for ()

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for String

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for bool

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for char

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for f32

Source

fn tot_eq(&self, other: &Self) -> bool

Source

impl TotalEq for f64

Source

fn tot_eq(&self, other: &Self) -> bool

Source

impl TotalEq for i8

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for i16

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for i32

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for i64

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for i128

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for isize

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for u8

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for u16

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for u32

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for u64

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for u128

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl TotalEq for usize

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl<T: TotalEq + ?Sized> TotalEq for &T

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Source

impl<T: TotalEq, U: TotalEq> TotalEq for (T, U)

Source

fn tot_eq(&self, other: &Self) -> bool

Source

impl<T: TotalEq> TotalEq for Option<T>

Source

fn tot_eq(&self, other: &Self) -> bool

Source

fn tot_ne(&self, other: &Self) -> bool

Implementors