TotalOrd

Trait TotalOrd 

pub trait TotalOrd: TotalEq {
    // Required method
    fn tot_cmp(&self, other: &Self) -> Ordering;

    // Provided methods
    fn tot_lt(&self, other: &Self) -> bool { ... }
    fn tot_gt(&self, other: &Self) -> bool { ... }
    fn tot_le(&self, other: &Self) -> bool { ... }
    fn tot_ge(&self, other: &Self) -> bool { ... }
}
Alternative trait for Ord. By consistently using this we can still be generic w.r.t Ord while getting a total ordering for floats.

Required Methods

fn tot_cmp(&self, other: &Self) -> Ordering

Provided Methods

fn tot_lt(&self, other: &Self) -> bool

fn tot_gt(&self, other: &Self) -> bool

fn tot_le(&self, other: &Self) -> bool

fn tot_ge(&self, other: &Self) -> bool

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl TotalOrd for &[u8]

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for &str

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for ()

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for String

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for bool

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for char

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for f32

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for f64

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for i8

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for i16

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for i32

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for i64

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for i128

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for isize

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for u8

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for u16

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for u32

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for u64

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for u128

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl TotalOrd for usize

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Source

impl<T: TotalOrd, U: TotalOrd> TotalOrd for (T, U)

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

impl<T: TotalOrd> TotalOrd for Option<T>

Source

fn tot_cmp(&self, other: &Self) -> Ordering

Source

fn tot_lt(&self, other: &Self) -> bool

Source

fn tot_gt(&self, other: &Self) -> bool

Source

fn tot_le(&self, other: &Self) -> bool

Source

fn tot_ge(&self, other: &Self) -> bool

Implementors