Module vec

Module vec 

Traits

PushUnchecked

Functions

reuse_vec
Re-uses the memory for a vec while clearing it. Allows casting the type of the vec at the same time. The stdlib specializes collect() to re-use the memory.
with_cast_mut_vec