pub fn iters_eq<L, R, T, U>(left: L, right: R) -> boolwhere
L: IntoIterator<Item = T>,
R: IntoIterator<Item = U>,
T: PartialEq<U>,
L::IntoIter: ExactSizeIterator,
R::IntoIter: ExactSizeIterator,Expand description
Returns true if both iterators have the same length, and the items at each index are equal.