pub fn tick_counter() -> u64Expand description
Unsynchronized tick counter.
This is intended to be used to roughly organize events across threads in their received order but without any actual guarantees around monotonicity or synchronization, for maximum speed.
This does not guarantee monotonicity or any particular (fixed) time unit. If correctness matters use Instant::now().